@@ -8,8 +8,8 @@ use lib "$FindBin::Bin/../lib";
 use Geo::Postcodes::JP::DB qw/make_database test_database/;
 
 my $postcode_file = "$FindBin::Bin/KEN_ALL.CSV";
-my $db_file = '/home/ben/projects/Geo-Postcodes-JP/xt/ken_all.db';
-my $schema_file = '/home/ben/projects/Geo-Postcodes-JP/db/schema.sql';
+my $db_file = "$FindBin::Bin/ken_all.db";
+my $schema_file = "$FindBin::Bin/../db/schema.sql";
 
 if (-f $db_file) {
     unlink $db_file or die $!;
